@@ -22,6 +22,7 @@
 Very high level interface to SNMP and MIB for Snimpy
 """
 
+from time import time
 from UserDict import DictMixin
 import snmp, mib, basictypes
 
@@ -33,27 +34,59 @@ class DelayedSetSession(object):
     """
 
     def __init__(self, session):
-        object.__setattr__(self, "session", session)
-        object.__setattr__(self, "setters", [])
+        self.session = session
+        self.setters = []
 
-    def __setattr__(self, attribute, value):
-        return setattr(object.__getattribute__(self, "session"), attribute)
-
-    def __getattribute__(self, attribute):
-        if attribute not in ["set", "commit"]:
-            return getattr(object.__getattribute__(self, "session"), attribute)
-        return object.__getattribute__(self, attribute)
-
-    def set(self, oid, value):
-        object.__getattribute__(self, "setters").append((oid, value))
+    def get(self, *args):
+        return self.session.get(*args)
+    def getnext(self, *args):
+        return self.session.getnext(*args)
+    def set(self, *args):
+        self.setters.extend(args)
 
     def commit(self):
-        args = []
-        for oid, value in object.__getattribute__(self, "setters"):
-            args.append(oid)
-            args.append(value)
-        if args:
-            object.__getattribute__(self, "session").set(*args)
+        if self.setters:
+            self.session.set(*self.setters)
+
+class CachedSession(object):
+    """SNMP session using a cache.
+
+    This is an adapter. The constructor takes the original session.
+    """
+
+    def __init__(self, session, timeout=5):
+        self.session = session
+        self.cache = {}
+        self.timeout = timeout
+        self.count = 0
+
+    def set(self, *args):
+        return self.session.set(*args)
+
+    def getorgetnext(self, op, *args):
+        self.count += 1
+        if (op, args) in self.cache:
+            t, v = self.cache[op, args]
+            if time() - t < self.timeout:
+                return v
+        value = getattr(self.session, op)(*args)
+        self.cache[op, args] = [time(), value]
+        self.flush()
+        return value
+
+    def get(self, *args):
+        return self.getorgetnext("get", *args)
+    def getnext(self, *args):
+        return self.getorgetnext("getnext", *args)
+
+    def flush(self):
+        if self.count < 1000:
+            return
+        keys = self.cache.keys()
+        for k in keys:
+            if time() - self.cache[k][0] > self.timeout:
+                del self.cache[k]
+        self.count = 0
 
 class Manager(object):
 
@@ -65,7 +98,7 @@ class Manager(object):
     # do we want this object to be populated with all nodes?
     _complete = False
 
-    def __init__(self, host=None, community=None, version=None):
+    def __init__(self, host=None, community=None, version=None, cache=False):
         if host is None:
             host = Manager._host
         self._host = host
@@ -74,6 +107,11 @@ class Manager(object):
         if version is None:
             version = Manager._version
         self._session = snmp.Session(host, community, version)
+        if cache:
+            if cache is True:
+                self._session = CachedSession(self._session)
+            else:
+                self._session = CachedSession(self._session, cache)
 
     def _locate(self, attribute):
         for m in loaded:
@@ -148,8 +186,10 @@ class ProxyColumn(Proxy, DictMixin):
                                                               indextype))
         oidindex = []
         for i, ind in enumerate(index):
-            if not isinstance(ind, basictypes.Type):
-                ind = indextype[i].type(indextype[i], ind)
+            ind = indextype[i].type(indextype[i], ind) # Cast to the
+                                                       # correct type
+                                                       # since we need
+                                                       # "toOid()"
             oidindex.extend(ind.toOid())
         result = getattr(self.session, op)(self.proxy.oid + tuple(oidindex), *args)
         if op != "set":
@@ -194,17 +234,9 @@ class ProxyColumn(Proxy, DictMixin):
             index = oid[len(self.proxy.oid):]
             target = []
             for x in indexes:
-                if not hasattr(x.type, "toOid"):
-                    raise ValueError("%s cannot be used as index" % str(x))
-                if x.type.consume == 0:
-                    target.append(x.type(x, tuple(index)))
-                    break
-                else:
-                    if len(index) < x.type.consume:
-                        raise ValueError("not enough OID left")
-                    target.append(x.type(x,
-                                         tuple(index[:x.type.consume])))
-                    index = index[x.type.consume:]
+                l, o = x.type.fromOid(x, tuple(index))
+                target.append(x.type(x, o))
+                index = index[l:]
             if len(target) == 1:
                 # Should work most of the time
                 yield target[0], result
