@@ -465,8 +465,8 @@ static struct typeConversion typeToPython[] = {
 	{ SMI_BASETYPE_INTEGER32, NULL, "Integer" },
 	{ SMI_BASETYPE_INTEGER64, NULL, "Integer" },
 	{ SMI_BASETYPE_UNSIGNED32, "TimeTicks", "Timeticks" },
-	{ SMI_BASETYPE_UNSIGNED32, NULL, "Integer" },
-	{ SMI_BASETYPE_UNSIGNED64, NULL, "Integer" },
+	{ SMI_BASETYPE_UNSIGNED32, NULL, "Unsigned32" },
+	{ SMI_BASETYPE_UNSIGNED64, NULL, "Unsigned64" },
 	{ SMI_BASETYPE_OCTETSTRING, "IpAddress", "IpAddress" },
 	{ SMI_BASETYPE_OCTETSTRING, NULL, "String" },
 	{ SMI_BASETYPE_OBJECTIDENTIFIER, NULL, "Oid" },
@@ -548,13 +548,13 @@ entity_getranges(EntityObject *self, void *closure)
 				cur = PyInt_FromLong(value->value.integer32);
 				break;
 			case SMI_BASETYPE_UNSIGNED32:
-				cur = PyInt_FromLong(value->value.unsigned32);
+				cur = PyLong_FromUnsignedLong(value->value.unsigned32);
 				break;
 			case SMI_BASETYPE_INTEGER64:
-				cur = PyLong_FromLong(value->value.integer64);
+				cur = PyLong_FromLongLong(value->value.integer64);
 				break;
 			case SMI_BASETYPE_UNSIGNED64:
-				cur = PyLong_FromUnsignedLong(value->value.unsigned64);
+				cur = PyLong_FromUnsignedLongLong(value->value.unsigned64);
 				break;
 			default:
 				cur = NULL;
@@ -700,6 +700,18 @@ mib_reset(PyObject *self)
 	return Py_None;
 }
 
+/* Check if a module exists and is conform. It should be used instead
+   of smiGetModule */
+static SmiModule*
+mib_get_module(const char *modulename)
+{
+	SmiModule *m;
+	if (((m = smiGetModule(modulename)) == NULL) ||
+	    ((m->conformance) && (m->conformance <= 1)))
+		return NULL;
+	return m;
+}
+
 static PyObject*
 mib_load(PyObject *self, PyObject *args)
 {
@@ -712,6 +724,12 @@ mib_load(PyObject *self, PyObject *args)
 		PyErr_Format(SmiException, "unable to load %s", module);
 		return NULL;
 	}
+	if (!mib_get_module(modulename)) {
+		PyErr_Format(SmiException,
+			     "%s contains major SMI errors (check with smilint)",
+			     module);
+		return NULL;
+	}
 	return PyString_FromString(modulename);
 }
 
@@ -725,7 +743,7 @@ mib_get_kind(PyObject *self, PyObject *args, int kind, PyObject *ObjectType)
 	PyObject *lnode;
 	if (!PyArg_ParseTuple(args, "s", &mib))
 		return NULL;
-	if ((module = smiGetModule(mib)) == NULL) {
+	if ((module = mib_get_module(mib)) == NULL) {
 		PyErr_Format(SmiException, "no module named %s", mib);
 		return NULL;
 	}
@@ -787,7 +805,7 @@ mib_get(PyObject* self, PyObject *args)
 
 	if (!PyArg_ParseTuple(args, "ss", &mib, &name))
 		return NULL;
-	if ((module = smiGetModule(mib)) == NULL) {
+	if ((module = mib_get_module(mib)) == NULL) {
 		PyErr_Format(SmiException, "no module named %s", mib);
 		return NULL;
 	}
