@@ -24,6 +24,7 @@ class TestMibSnimpy(unittest.TestCase):
                         "snimpySimpleType",
                         "snimpyIndexVarLen",
                         "snimpyIndexIntIndex",
+                        "snimpyIndexOidVarLen",
                         "snimpyIndexFixedLen",
                         "snimpyIndexImplied",
                         "snimpyIndexInt",
@@ -128,10 +129,10 @@ class TestMibSnimpy(unittest.TestCase):
                "snimpyEnum": basictypes.Enum,
                "snimpyObjectId": basictypes.Oid,
                "snimpyBoolean": basictypes.Boolean,
-               "snimpyCounter": basictypes.Integer,
-               "snimpyGauge": basictypes.Integer,
+               "snimpyCounter": basictypes.Unsigned32,
+               "snimpyGauge": basictypes.Unsigned32,
                "snimpyTimeticks": basictypes.Timeticks,
-               "snimpyCounter64": basictypes.Integer,
+               "snimpyCounter64": basictypes.Unsigned64,
                "snimpyBits": basictypes.Bits,
                "snimpySimpleIndex": basictypes.Integer,
                "snimpyComplexFirstIP": basictypes.IpAddress,
@@ -207,6 +208,15 @@ class TestMibSnimpy(unittest.TestCase):
         """Check that we get an exception when loading an inexistant module"""
         self.assertRaises(mib.SMIException, mib.load, "idontexist.gfdgfdg")
 
+    def testLoadInvalidModule(self):
+        """Check that an obviously invalid module cannot be loaded"""
+        path = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                            "SNIMPY-INVALID-MIB.mib")
+        self.assertRaises(mib.SMIException, mib.load, path)
+        self.assertRaises(mib.SMIException, mib.getNodes, "SNIMPY-INVALID-MIB")
+        self.assertRaises(mib.SMIException, mib.get,
+                          "SNIMPY-INVALID-MIB", "invalidSnimpyNode")
+
     def testAccesInexistantModule(self):
         """Check that we get an exception when querying inexistant module"""
         self.assertRaises(mib.SMIException, mib.getNodes, "idontexist.kjgf");
